[![PyPI](https://img.shields.io/pypi/v/SC2Spa?logo=PyPI)](https://pypi.org/project/SC2Spa)
[![Docs](https://img.shields.io/readthedocs/sc2spa)](https://sc2spa.readthedocs.io)

SC2Spa: a deep learning based approach to map transcriptome to spatial origins at cellular resolution
====================================================================================

<p align="center">
  <img src="./SC2Spa.png" alt="SC2Spa Overview" width="600"/>
</p>

## Install
Install SC2Spa:
```
conda create -n SC2Spa python=3.9
conda activate SC2Spa
pip install SC2Spa
```

## Analysis for the SC2Spa manuscript
The analysis for the SC2Spa manuscript can be found in [this repository](https://github.com/linbuliao/SC2Spa_Notebooks).
The analysis and related data were also uploaded to [Figshare](https://figshare.com/articles/dataset/Datasets_for_high_resolution_spatial_mapping_of_mouse_hippocampus_Slide-seqV2_for_SC2Spa/21829905/8) and [Zenodo](https://zenodo.org/records/8252715).

## Many more to come!
We will update more on our [Read the Docs page](https://sc2spa.readthedocs.io/en/latest/)

## News

__2023/08/22__

SC2Spa is now on BioRXiv!
https://www.biorxiv.org/content/10.1101/2023.08.22.554277v1
